\name{convertScreenUnits}
\alias{convertScreenUnits}
\title{Attempt to convert between npc, inches, and pixels on the screen.}
\usage{
  convertScreenUnits(value, from, to,
    type = c("width", "height"))
}
\arguments{
  \item{value}{value to convert}

  \item{from}{unit to convert from. See Details.}

  \item{to}{unit to convert to. See Details.}

  \item{type}{either 'width' or 'height'. Only of use for
  'npc' conversions -- whether you want to return a
  fraction of the height or of the width.}
}
\value{
  the converted unit
}
\description{
  Attempt to convert between npc, inches, and pixels on the
  screen.
}
\details{
  The available units are: \describe{ \item{inches}{Inches}
  \item{npc}{Normalised Parent Coordinates: the entire
  monitor has dimensions (1,1).} \item{pixels}{pixels} }

  ** The conversions are rough only and not exact! Also,
  'npc' conversions may screw up with dual monitor!  **

  The conversion between pixels and inches uses
  \code{imageUtilities.option('ppi')} (pixels per inch),
  which is default 96.

  The conversion between pixels or inches and screen size
  uses the function \code{\link{getScreenResolution}},
  which doesn't always work. If the code is unable to
  return the screen resolution, a default value of
  \code{imageUtilities.option('default.screen.resolution')}
  is used (currently 1280 x 1024).
}
\examples{
# convert 7 screen inches to screen pixels (approx).
convertScreenUnits(7,from='inches',to='pixels')
# find out what half the screen width is in inches
convertScreenUnits(.5,from='npc',to='inches',type='width')
# find out what fraction of the screen height 2 inches is.
convertScreenUnits(2,from='inches',to='npc',type='height')
}
\seealso{
  \code{\link{imageUtilities.option}}

  Other units: \code{\link{getPPI}},
  \code{\link{getScreenResolution}}, \code{\link{unitType}}
}

