\name{drawImage}
\alias{drawImage}
\title{plots an image on an R device using the "grid" package.}
\usage{
  drawImage(img, max = imageUtilities.option("max"),
    dev.new = TRUE, maxWidth = unit(7, "inches"),
    resize = FALSE,
    transpose = imageUtilities.option(".using.Voir"), ...)
}
\arguments{
  \item{img}{a heightxwidthxchannels *array* with the
  number of channels}

  \item{max}{max intensity of image}

  \item{dev.new}{whether to open up new device (sometimes
  may be nice not to in order to draw on an existing
  device).}

  \item{transpose}{boolean, whether to transpose image
  before drawing (should not need to be used -- just for
  compatibility between Voir and non-Voir versions of the
  package)}

  \item{maxWidth}{the maximum width the image should be.
  Can be either a number (in which case it will be
  interpreted as *pixels*), or a unit of the form
  \code{unit(width,type)} where \code{type} is one of 'npc'
  or 'inches' (see \code{\link{convertScreenUnits}}). The
  *display* will be resized to approximately this size
  (although the image displayed will not be subsampled in
  any way). However, if parameter \code{resize} is
  \code{TRUE}, this changes the behaviour.}

  \item{resize}{boolean. If this is set to TRUE, then
  instead of resizing the *display* to \code{maxWidth}, the
  *image* will be subsampled to this size (although the
  scale will still be as for the full-size image so that
  \code{grid.locator()} still returns the right
  coordinates.}

  \item{...}{passed into \code{viewport} command used to
  draw the image.}
}
\value{
  handle to the viewport.
}
\description{
  plots an image on an R device using the "grid" package.
}
\note{
  The coordinate system is set up such that the *middle* of
  the top-left pixel has coordinates (1,1) (ie 1-based).  Y
  increases downwards and X increases left-to-right (ie, an
  i-j coordinate system).

  The middles of pixels have integer coordinates.
}
\seealso{
  Other draw: \code{\link{imdisp}},
  \code{\link{imdrawabline}}, \code{\link{imdrawline}},
  \code{\link{plotPoints}}, \code{\link{pointPicker}}
}

