\name{imageUtilities.options}
\alias{imageUtilities.option}
\alias{imageUtilities.options}
\title{Provides a means to control the behaviour of the "imageUtilities" package.}
\usage{
  imageUtilities.options(...)

  imageUtilities.option(name)
}
\arguments{
  \item{...}{a list may be given as the only argument, or
  any number of arguments may be in the \code{name=value}
  form, or no argument at all may be given to list all
  current options. See Value and Details section for
  explanation.

  Arguments which are set by a function call will remain in
  effect until the end of the current session, unless
  overwritten by a subsequent call.

  Current options are: \describe{ \item{max}{the default
  maximum intensity of images. In the Voir version of
  imageUtilities, this is 255. In the non-Voir version,
  this is 1. Mainly pertinent for overlaying and displaying
  images using the grid package.}
  \item{.using.Voir}{whether the package is using the Voir
  backend.  currently unused, and **DON'T** modify it.}
  \item{ppi}{integer, pixels per inch. Default 96. Used in
  \code{\link{convertScreenUnits}}, which is itself mainly
  used in trying to make an R graphics device fit on the
  screen nicely.} \item{default.screen.resolution}{the
  default screen resolution to use if one can't be
  determined (again, only used to make an R graphics device
  fit on the screen nicely, not crucial). 1280x1024.} }}

  \item{name}{the name of the option to retrieve.}
}
\value{
  a list with the updated values of the parameters. If the
  argument list is not empty, the returned list is
  invisible.
}
\description{
  Provides a means to control the behaviour of the
  "imageUtilities" package.
}
\details{
  The parameter values set via a call to this function will
  remain in effect for the rest of the session, affecting
  the subsequent behaviour of the other functions of the
  "imageUtilities" package for which the given parameters
  are relevant.

  The \code{imageUtilities.option(optname)} form retrieves
  *one* option in *non-list* form, wherease the
  \code{imageUtilities.options(optname)} form retrieves the
  option(s) in *list* form (even if there is only one).
}
\examples{
\dontrun{
imageUtilities.options(max=255)
# in overlay functions/display functions using the grid package, a
# maximum intensity of 255 will be assumed.
}
}

